==> owncloud-4.0.4.tgz: owncloud/core/l10n/pt_PT.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Nome da aplicação não definida.",
"No category to add?" => "Nenhuma categoria para adicionar?",
"This category already exists: " => "Esta categoria já existe:",
"Owncloud password reset" => "Redefinir palavra-chave ownCloud",
"ownCloud password reset" => "Reposição da password ownCloud",
"Use the following link to reset your password: {link}" => "Use o seguinte endereço para repor a sua password: {link}",
"You will receive a link to reset your password via Email." => "Vai receber um endereço para repor a sua password",
"Requested" => "Pedido",
"Login failed!" => "Conexão falhado!",
"Username" => "Utilizador",
"Request reset" => "Pedir reposição",
"Your password was reset" => "A sua password foi reposta",
"To login page" => "Para a página de conexão",
"New password" => "Nova password",
"Reset password" => "Repor password",
"Personal" => "Pessoal",
"Users" => "Utilizadores",
"Apps" => "Aplicações",
"Admin" => "Admin",
"Help" => "Ajuda",
"Access forbidden" => "Acesso interdito",
"Cloud not found" => "Cloud nao encontrada",
"Edit categories" => "Editar categorias",
"Add" => "Adicionar",
"Create an <strong>admin account</strong>" => "Criar uma <strong>conta administrativa</strong>",
"Password" => "Palavra chave",
"Advanced" => "Avançado",
"Data folder" => "Pasta de dados",
"Configure the database" => "Configure a base de dados",
"will be used" => "vai ser usada",
"Database user" => "Utilizador da base de dados",
"Database password" => "Password da base de dados",
"Database name" => "Nome da base de dados",
"Database host" => "Host da base de dados",
"Finish setup" => "Acabar instalação",
"web services under your control" => "serviços web sob o seu controlo",
"Log out" => "Sair",
"Settings" => "Definições",
"Lost your password?" => "Esqueceu a sua password?",
"remember" => "lembrar",
"Log in" => "Entrar",
"You are logged out." => "Estás desconetado.",
"prev" => "anterior",
"next" => "seguinte"
);

==> owncloud-4.5.7.tgz: owncloud/core/l10n/pt_PT.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Nome da aplicação não definida.",
"No category to add?" => "Nenhuma categoria para adicionar?",
"This category already exists: " => "Esta categoria já existe:",
"Settings" => "Definições",
"January" => "Janeiro",
"February" => "Fevereiro",
"March" => "Março",
"April" => "Abril",
"May" => "Maio",
"June" => "Junho",
"July" => "Julho",
"August" => "Agosto",
"September" => "Setembro",
"October" => "Outubro",
"November" => "Novembro",
"December" => "Dezembro",
"Cancel" => "Cancelar",
"No" => "Não",
"Yes" => "Sim",
"Ok" => "Ok",
"No categories selected for deletion." => "Nenhuma categoria seleccionar para eliminar",
"Error" => "Erro",
"Password" => "Palavra chave",
"ownCloud password reset" => "Reposição da password ownCloud",
"Use the following link to reset your password: {link}" => "Use o seguinte endereço para repor a sua password: {link}",
"You will receive a link to reset your password via Email." => "Vai receber um endereço para repor a sua password",
"Requested" => "Pedido",
"Login failed!" => "Conexão falhado!",
"Username" => "Utilizador",
"Request reset" => "Pedir reposição",
"Your password was reset" => "A sua password foi reposta",
"To login page" => "Para a página de conexão",
"New password" => "Nova password",
"Reset password" => "Repor password",
"Personal" => "Pessoal",
"Users" => "Utilizadores",
"Apps" => "Aplicações",
"Admin" => "Admin",
"Help" => "Ajuda",
"Access forbidden" => "Acesso interdito",
"Cloud not found" => "Cloud nao encontrada",
"Edit categories" => "Editar categorias",
"Add" => "Adicionar",
"Create an <strong>admin account</strong>" => "Criar uma <strong>conta administrativa</strong>",
"Advanced" => "Avançado",
"Data folder" => "Pasta de dados",
"Configure the database" => "Configure a base de dados",
"will be used" => "vai ser usada",
"Database user" => "Utilizador da base de dados",
"Database password" => "Password da base de dados",
"Database name" => "Nome da base de dados",
"Database host" => "Host da base de dados",
"Finish setup" => "Acabar instalação",
"web services under your control" => "serviços web sob o seu controlo",
"Log out" => "Sair",
"Lost your password?" => "Esqueceu a sua password?",
"remember" => "lembrar",
"Log in" => "Entrar",
"You are logged out." => "Estás desconetado.",
"prev" => "anterior",
"next" => "seguinte"
);
